pub enum DatabaseCommand {
Remove {
dates: Vec<String>,
},
Count,
Update,
Show,
Purge,
Clean {
all: bool,
},
Refresh,
Store {
dates: Vec<String>,
},
}Variants
Remove
Removes specified date(s) from database if present.
Writes number removed to STDOUT
Count
Gets a count of the rows in the db.
Writes num to STDOUT
Update
Adds entries from the web to the database
Show
Shows all of the lectionary rows in the database
Prints every row of the lectionary table, sorted by date, as “[date] [name]”
Purge
Deletes all data in the database
Writes number of rows removed to STDOUT
Clean
Deletes old entries from the database
Uses values defined in the config
Refresh
Equivalent of db clean + db update
Store
Stores specified dates in to the database if they are not present
Writes number of new entries to STDOUT